@@ -20,11 +20,7 @@ sys.path.append(os.path.join(splunkhome, "etc", "apps", "trackme", "lib"))
 
 from trackme_libs import trackme_reqinfo, trackme_idx_for_tenant, trackme_state_event
 
-# import cim_modactions
-modaction_path = os.path.join(
-    splunkhome, "etc", "apps", "Splunk_SA_CIM", "lib", "cim_actions.py"
-)
-import cim_actions
+from splunktaucclib.cim_actions import parse_mv
 
 
 def get_splunk_service(helper, session_key, server_uri):
@@ -57,7 +53,7 @@ def process_event(helper, *args, **kwargs):
             # Check if there is a multi-value field and parse it if present
             mv_field = f"__mv_{field}"
             if mv_field in event:
-                parsed_value = cim_actions.parse_mv(event[mv_field])
+                parsed_value = parse_mv(event[mv_field])
                 # If the parsed multi-value field is empty, use the single-value field
                 if parsed_value:
                     value = parsed_value
